@@ -3,12 +3,13 @@
 from .dto.action.action import Action
 from .dto.action.action_queue import ActionQueue
 from .dto.user.event import UserEvent
-from .dto.user.feature import UserFeature
+from .dto.user.feature_state import UserFeatureState
 from .dto.user.income import UserIncome
 from .dto.user.notification import UserNotification
 from .dto.user.state import UserState
 from .dto.user.store import UserStore
 from .dto.user.user import User
+from .feature_details import FeatureDetails
 from .feature_type import FeatureType
 from .store_type import StoreType
 from .user_event_other_type import UserEventOtherType
