@@ -2,9 +2,9 @@
 
 from pydantic import BaseModel
 
+from ...feature_details import FeatureDetails
 from ...feature_type import FeatureType
 from ...store_type import StoreType
-from .feature import UserFeature
 from .income import UserIncome
 from .notification import UserNotification
 from .store import UserStore
@@ -23,10 +23,12 @@ class UserState(BaseModel):
         A dictionary of user stores, keyed by store name.
     incomes: dict[StoreType, UserIncome]
         A dictionary of user incomes, keyed by income name.
-    features: dict[FeatureType, UserFeature]
-        A dictionary of user features, keyed by feature name.
+    features: set(FeatureType)
+        A set of user features.
     active_feature: FeatureType
         The current active user feature (location the user is currently in).
+    active_feature_state: FeatureDetails
+        The active feature details.
     population: int
         The size of the user population.
     merchants: set[StoreType]
@@ -38,8 +40,9 @@ class UserState(BaseModel):
     active: bool
     stores: dict[StoreType, UserStore]
     incomes: dict[StoreType, UserIncome]
-    features: dict[FeatureType, UserFeature]
+    features: set[FeatureType]
     active_feature: FeatureType
+    active_feature_state: FeatureDetails
     population: int
     merchants: set[StoreType]
     notifications: list[UserNotification]
